<template>
  <BasePage>
    <form @submit.prevent="submitStkPush">
      <BasePageHeader :title="pageTitle">
        <BaseBreadcrumb>
          <BaseBreadcrumbItem :title="$t('general.home')" to="dashboard" />

          <BaseBreadcrumbItem
            :title="$t('customers.customer', 2)"
            to="/admin/customers"
          />

          <BaseBreadcrumb-item :title="pageTitle" to="#" active />
        </BaseBreadcrumb>

        <template #actions>
          <div class="flex items-center justify-end">
            <BaseButton type="submit" :loading="isSaving" :disabled="isSaving">
              <template #left="slotProps">
                <BaseIcon name="SaveIcon" :class="slotProps.class" />
              </template>
              {{
                isEdit
                  ? $t('mpesa.update_customer')
                  : $t('mpesa.save_customer')
              }}
            </BaseButton>
          </div>
        </template>
      </BasePageHeader>

      <BaseCard class="mt-5">
        <!-- Basic Info -->
        <div class="grid grid-cols-5 gap-4 mb-8">
          <h6 class="col-span-5 text-lg font-semibold text-left lg:col-span-1">
            {{ $t('customers.basic_info') }}
          </h6>

          <BaseInputGrid class="col-span-5 lg:col-span-4">
            <BaseInputGroup
              :label="$t('mpesa.phone')"
              required
              :error="
                v$.currentMpesa.phone_number.$error &&
                v$.currentMpesa.phone_number.$errors[0].$message
              "
              :content-loading="isFetchingInitialData"
            >
              <BaseInput
                v-model="mpesaStore.currentMpesa.phone_number"
                :content-loading="isFetchingInitialData"
                type="text"
                name="name"
                class=""
                :invalid="v$.currentMpesa.phone_number.$error"
                @input="v$.currentMpesa.phone_number.$touch()"
              />
            </BaseInputGroup>

            <BaseInputGroup
              :label="$t('mpesa.account_reference')"
              required
              :error="
                v$.currentMpesa.account_reference.$error &&
                v$.currentMpesa.account_reference.$errors[0].$message
              "
              :content-loading="isFetchingInitialData"
            >
              <BaseInput
                v-model.trim="mpesaStore.currentMpesa.account_reference"
                :content-loading="isFetchingInitialData"
                type="text"
                :invalid="v$.currentMpesa.account_reference.$error"
                @input="v$.currentMpesa.account_reference.$touch()"
              />
            </BaseInputGroup>

            <BaseInputGroup
              :label="$t('mpesa.amount')"
              required
              :error="
                v$.currentMpesa.amount.$error &&
                v$.currentMpesa.amount.$errors[0].$message
              "
              :content-loading="isFetchingInitialData"
            >
              <BaseInput
                v-model.trim="mpesaStore.currentMpesa.amount"
                :content-loading="isFetchingInitialData"
                type="text"
                :invalid="v$.currentMpesa.amount.$error"
                @input="v$.currentMpesa.amount.$touch()"
              />
            </BaseInputGroup>

          </BaseInputGrid>
        </div>


      </BaseCard>
    </form>
  </BasePage>
</template>

<script setup>
import { computed, onMounted, ref } from 'vue'
import { useRoute, useRouter } from 'vue-router'
import { useI18n } from 'vue-i18n'
import {
  required,
  minLength,
  url,
  maxLength,
  helpers,
  email,
  sameAs,
  requiredIf,
} from '@vuelidate/validators'
import useVuelidate from '@vuelidate/core'
import { useMpesaStore } from '@/scripts/admin/stores/mpesa'
import { useCustomerStore } from '@/scripts/admin/stores/customer'
import { useCustomFieldStore } from '@/scripts/admin/stores/custom-field'
import CustomerCustomFields from '@/scripts/admin/components/custom-fields/CreateCustomFields.vue'
import { useGlobalStore } from '@/scripts/admin/stores/global'
import CopyInputField from '@/scripts/admin/components/CopyInputField.vue'
import { useCompanyStore } from '@/scripts/admin/stores/company'

const customerStore = useCustomerStore()
const mpesaStore = useMpesaStore()
const customFieldStore = useCustomFieldStore()
const globalStore = useGlobalStore()
const companyStore = useCompanyStore()

const customFieldValidationScope = 'customFields'

const { t } = useI18n()

const router = useRouter()
const route = useRoute()

let isFetchingInitialData = ref(false)
let isShowPassword = ref(false)
let isShowConfirmPassword = ref(false)

let active = ref(false)
const isSaving = ref(false)

const isEdit = computed(() => route.name === 'mpesa.edit')

let isLoadingContent = computed(() => customerStore.isFetchingInitialSettings)

const pageTitle = computed(() =>
  isEdit.value ? t('mpesa.edit_transaction') : t('mpesa.new_transaction')
)

// const rules = computed(() => {
//   return {
//     currentCustomer: {
//       name: {
//         required: helpers.withMessage(t('validation.required'), required),
//         minLength: helpers.withMessage(
//           t('validation.name_min_length', { count: 3 }),
//           minLength(3)
//         ),
//       },
//       prefix: {
//         minLength: helpers.withMessage(
//           t('validation.name_min_length', { count: 3 }),
//           minLength(3)
//         ),
//       },
//       currency_id: {
//         required: helpers.withMessage(t('validation.required'), required),
//       },
//
//       email: {
//         required: helpers.withMessage(
//           t('validation.required'),
//           requiredIf(customerStore.currentCustomer.enable_portal == true)
//         ),
//         email: helpers.withMessage(t('validation.email_incorrect'), email),
//       },
//       password: {
//         required: helpers.withMessage(
//           t('validation.required'),
//           requiredIf(
//             customerStore.currentCustomer.enable_portal == true &&
//               !customerStore.currentCustomer.password_added
//           )
//         ),
//         minLength: helpers.withMessage(
//           t('validation.password_min_length', { count: 8 }),
//           minLength(8)
//         ),
//       },
//       confirm_password: {
//         sameAsPassword: helpers.withMessage(
//           t('validation.password_incorrect'),
//           sameAs(customerStore.currentCustomer.password)
//         ),
//       },
//
//       website: {
//         url: helpers.withMessage(t('validation.invalid_url'), url),
//       },
//       billing: {
//         address_street_1: {
//           maxLength: helpers.withMessage(
//             t('validation.address_maxlength', { count: 255 }),
//             maxLength(255)
//           ),
//         },
//
//         address_street_2: {
//           maxLength: helpers.withMessage(
//             t('validation.address_maxlength', { count: 255 }),
//             maxLength(255)
//           ),
//         },
//       },
//
//       shipping: {
//         address_street_1: {
//           maxLength: helpers.withMessage(
//             t('validation.address_maxlength', { count: 255 }),
//             maxLength(255)
//           ),
//         },
//
//         address_street_2: {
//           maxLength: helpers.withMessage(
//             t('validation.address_maxlength', { count: 255 }),
//             maxLength(255)
//           ),
//         },
//       },
//     },
//   }
// })
const rules = computed(() => {
  return {
    currentMpesa: {
      phone_number: {
        required: helpers.withMessage(t('validation.required'), required),
        // minLength: helpers.withMessage(
        //   t('validation.name_min_length', { count: 9 }),
        //   minLength(9)
        // ),
      },
      account_reference: {
        required: helpers.withMessage(t('validation.required'), required),
        // minLength: helpers.withMessage(
        //   t('validation.name_min_length', { count: 12 }),
        //   minLength(12)
        // ),
      },
      amount: {
        required: helpers.withMessage(t('validation.required'), required),
      },
    },
  }
})

const getCustomerPortalUrl = computed(() => {
  return `${window.location.origin}/${companyStore.selectedCompany.slug}/customer/login`
})

const v$ = useVuelidate(rules, mpesaStore, {
  $scope: customFieldValidationScope,
})

mpesaStore.resetCurrentCustomer()
// customerStore.resetCurrentCustomer()

mpesaStore.fetchCustomerInitialSettings(isEdit.value)

// async function submitCustomerData() {
//   v$.value.$touch()
//
//   if (v$.value.$invalid) {
//     return true
//   }
//
//   isSaving.value = true
//
//   let data = {
//     ...customerStore.currentCustomer,
//   }
//
//   let response = null
//
//   try {
//     const action = isEdit.value
//       ? customerStore.updateCustomer
//       : customerStore.addCustomer
//     response = await action(data)
//   } catch (err) {
//     isSaving.value = false
//     return
//   }
//
//   router.push(`/admin/customers/${response.data.data.id}/view`)
// }
async function submitStkPush() {
  v$.value.$touch()

  if (v$.value.$invalid) {
    return true
  }

  isSaving.value = true

  let data = {
    ...mpesaStore.currentMpesa,
  }

  let response = null

  try {
    const action = isEdit.value
      ? mpesaStore.updateCustomer
      : mpesaStore.addCustomer
    response = await action(data)
  } catch (err) {
    isSaving.value = false
    return
  }

  router.push(`/admin/mpesa/${response.data.data.id}/view`)
}
</script>
